Orquestra Core
==============

Orquestra\ :sup:`®` Core is a collection of open-source Python libraries for developing quantum applications. It includes a :doc:`Workflow SDK <sdk/index>` for defining and managing computational workflows and a :doc:`Quantum SDK <quantum/index>` for expressing quantum algorithms and interfacing with quantum hardware.

.. button-ref:: getting_started
   :color: primary
   :shadow:

    Get started with Orquestra Core

Featured tutorials
------------------

.. grid:: 2
   :gutter: 3 3 4 5

   .. grid-item-card:: Circuit Basics 
      :link: quantum/tutorials/basic_qaoa
      :link-type: doc
      
      Learn how to create and manipulate quantum circuits using the Orquestra Quantum SDK.

   .. grid-item-card:: Solve MaxCut with QAOA
      :link: quantum/tutorials/basic_qaoa
      :link-type: doc
      
      An end-to-end example of using Quantum Approximate Optimization Algorithm (QAOA) to solve the maximum cut problem.

   .. grid-item-card:: Using the Workflow SDK with Jupyter Notebooks
      :link: sdk/tutorials/jupyter-sdk
      :link-type: doc

      Learn how to compose, execute, and manage computational workflows from within a Jupyter notebook.

   .. grid-item-card:: VQE with IBM Quantum
      :link: sdk/recipes/vqe
      :link-type: doc

      Use Orquestra Workflow and Quantum SDKs to compare VQE results on different IBM backends.

.. toctree::
   :hidden:

   Getting Started<getting_started>
   Workflow SDK <sdk/index>
   Quantum SDK <quantum/index>
